@@ -1,4 +1,4 @@
-;;;; -*- Mode: Lisp; Syntax: ANSI-Common-Lisp; Base: 10; Package: kmrcl-*-
+;;;; -*- Mode: Lisp; Syntax: ANSI-Common-Lisp; Base: 10-*-
 ;;;; *************************************************************************
 ;;;; FILE IDENTIFICATION
 ;;;;
@@ -7,9 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id$
-;;;;
-;;;; This file, part of KMRCL, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
+;;;; This file, part of KMRCL, is Copyright (c) 2002-2010 by Kevin M. Rosenberg
 ;;;;
 ;;;; KMRCL users are granted the rights to distribute and use this software
 ;;;; as governed by the terms of the Lisp Lesser GNU Public License
@@ -41,22 +39,22 @@ on example from AMOP"))
 ;; encapsulating macro for Lispworks
 (kmr-mop:process-slot-option attributes-class :attributes)
 
-#+(or cmu scl sbcl openmcl)
+#+(or cmu scl sbcl ccl)
 (defmethod kmr-mop:validate-superclass ((class attributes-class)
                                         (superclass kmr-mop:standard-class))
   t)
 
-(defmethod kmr-mop:direct-slot-definition-class ((cl attributes-class) #+kmr-normal-dsdc &rest initargs)
+(defmethod kmr-mop:direct-slot-definition-class ((cl attributes-class) #+kmrcl::normal-dsdc &rest initargs)
   (declare (ignore initargs))
   (kmr-mop:find-class 'attributes-dsd))
 
-(defmethod kmr-mop:effective-slot-definition-class ((cl attributes-class) #+kmr-normal-dsdc &rest initargs)
+(defmethod kmr-mop:effective-slot-definition-class ((cl attributes-class) #+kmrcl::normal-dsdc &rest initargs)
   (declare (ignore initargs))
   (kmr-mop:find-class 'attributes-esd))
 
 (defmethod kmr-mop:compute-effective-slot-definition
-    ((cl attributes-class) #+kmr-normal-cesd name dsds)
-  #+kmr-normal-cesd (declare (ignore name))
+    ((cl attributes-class) #+kmrcl::normal-cesd name dsds)
+  #+kmrcl::normal-cesd (declare (ignore name))
   (let ((esd (call-next-method)))
     (setf (esd-attributes esd) (remove-duplicates (mapappend #'dsd-attributes dsds)))
     esd))
