@@ -94,12 +94,12 @@ Make-Byte-Array-Output-Stream since the last call to this function."
 #+sbcl
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (sb-ext:without-package-locks
-      (defvar *system-copy-fn* (if (fboundp (intern "COPY-SYSTEM-AREA" "SB-KERNEL"))
-                                   (intern "COPY-SYSTEM-AREA" "SB-KERNEL")
-                                   (intern "COPY-SYSTEM-UB8-AREA" "SB-KERNEL")))
-    (defconstant +system-copy-multiplier+ (if (fboundp (intern "COPY-FROM-SYSTEM-AREA" "SB-KERNEL"))
-                                              sb-vm:n-byte-bits
-                                         1))))
+      (sb-ext:without-package-locks
+          (defvar *system-copy-fn* (intern "SYSTEM-AREA-UB8-COPY" "SB-KERNEL"))
+          (defconstant +system-copy-multiplier+
+            (if (fboundp (intern "COPY-UB8-FROM-SYSTEM-AREA" "SB-KERNEL"))
+                sb-vm:n-byte-bits
+                1)))))
 
 #+(or cmu sbcl)
 (progn
@@ -264,5 +264,3 @@ Make-Byte-Array-Output-Stream since the last call to this function."
                                                         (end (length buffer)))
     (excl:make-buffer-input-stream buffer start end :octets))
   ) ;; progn
-
-
