@@ -105,7 +105,7 @@
     #+gcl (lisp:bye code)
     #+lispworks (lw:quit :status code)
     #+lucid (lcl:quit code)
-    #+sbcl (sb-ext:quit :unix-status (typecase code (number code) (null 0) (t 1)))
+    #+sbcl (sb-ext:exit :code (typecase code (number code) (null 0) (t 1)))
     #+mcl (ccl:quit code)
     #-(or allegro clisp cmu scl cormanlisp gcl lispworks lucid sbcl mcl)
     (error 'not-implemented :proc (list 'quit code)))
