@@ -7,8 +7,6 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Jul 2003
 ;;;;
-;;;; $Id$
-;;;;
 ;;;; *************************************************************************
 
 (in-package #:kmrcl)
@@ -156,7 +154,8 @@ returns (VALUES output-string pid)"
   (when (probe-file file)
     #+allegro (let ((stat (excl.osi:stat (namestring file))))
                 (excl.osi:stat-size stat))
-    #-allegro
+    #+sbcl (sb-posix:stat-size (sb-posix:stat file))
+    #-(or allegro sbcl)
     (with-open-file (in file :direction :input)
       (file-length in))))
 
