@@ -218,6 +218,8 @@
    #:print-separated-strings
    #:lex-string
    #:split-alphanumeric-string
+   #:safely-read-from-string
+   #:parse-float
 
    ;; strmatch.lisp
    #:score-multiword-match
